Imports ServerSIP.ServerSIP

Public Class LineForm

    Public Sub New()
        InitializeComponent()
        RadioRejectCall.Checked = True
    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub BtnAddLine_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnAddLine.Click

        If AddLineChecks() = False Then
            Return
        End If

        If ComboLine.FindStringExact(ComboLine.Text) <> -1 Then
            If MessageBox.Show("Line already exists, do you want to continue?", "VaxVoIP", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) = DialogResult.No Then
                Return
            End If
        End If

        '//////////////////////////////////////////////////////////////////////////

        Dim sToPeerName As String = "", sRoomName As String = ""
        Dim bRejected As Boolean = False

        GetIncomingCallInfo(sToPeerName, bRejected, sRoomName)

        '//////////////////////////////////////////////////////////////////////////

        Dim sCodec As String = GetAudioCodecUI()
        Dim nLineType As Integer = GetLineTypeUI()

        '//////////////////////////////////////////////////////////////////////////

        If cVaxLine.AddLine(ComboLine.Text, nLineType, EditAuthUser.Text, EditPassword.Text, EditServerAddr.Text, Convert.ToInt32(EditServerPort.Text), sCodec, CheckBoxRegLine.Checked, sToPeerName, bRejected, sRoomName) = False Then
            MessageBox.Show("Line could not be added or Please start the server first.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.[Error])
            Return
        End If

        If Not ComboLine.Items.Contains(ComboLine.Text) Then
            ComboLine.Items.Add(ComboLine.Text)
        End If

        MessageBox.Show("Line added/updated successfully.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)

    End Sub

    Private Sub BtnRemoveLine_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnRemoveLine.Click

        If ComboLine.Text.Length = 0 Then
            MessageBox.Show("Please enter line name.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return
        End If

        Dim nIndex As Integer = ComboLine.FindStringExact(ComboLine.Text)
        If nIndex = -1 Then Return

        cVaxLine.RemoveLine(ComboLine.Text)
        ComboLine.Items.RemoveAt(nIndex)

        ClearDlgUI()

        If ComboLine.Items.Count > 0 Then
            ComboLine.SelectedIndex = 0
        End If

        ShowLineDetails()
        MessageBox.Show("Line removed successfully!", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub ComboLine_SelectedIndexChanged(ByVal sender As Object, ByVal e As EventArgs) Handles ComboLine.SelectedIndexChanged
        ShowLineDetails()
    End Sub

    Private Sub BtnClearLine_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnClearLineDlg.Click
        ClearDlgUI()
    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Public Sub OnSetActive()

        AddUsers()
        AddRooms()

        AddLines()
        ShowLineDetails()

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub ShowLineDetails()

        Dim sLineName As String = ComboLine.Text
        If sLineName.Length = 0 Then Return

        Dim sAuthUser As String = "", sAuthPwd As String = "", sServerAddr As String = ""
        Dim sAudioCodecList As String = "", sToPeerName As String = "", sRoomName As String = ""

        Dim nServerPort As Integer = cVaxServerCOM.SIP_DEFAULT_PORT, nLineType As Integer = cVaxServerCOM.VAX_LINE_TYPE_UDP
        Dim bRegister As Boolean = False, bRejected As Boolean = False

        cStoreLine.GetLine(sLineName, nLineType, sAuthUser, sAuthPwd, sServerAddr, nServerPort, sAudioCodecList, bRegister, sToPeerName, bRejected, sRoomName)
        UpdateDlgUI(sLineName, nLineType, sAuthUser, sAuthPwd, sServerAddr, nServerPort, sAudioCodecList, bRegister, sToPeerName, bRejected, sRoomName)

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub UpdateDlgUI(ByVal sLineName As String, ByVal nLineType As Integer, ByVal sAuthUser As String, ByVal sAuthPwd As String, ByVal sServerAddr As String, ByVal nServerPort As Integer, ByVal sAudioCodecList As String, ByVal bRegister As Boolean, ByVal sToPeerName As String, ByVal bRejected As Boolean, ByVal sRoomName As String)

        If sLineName.Length = 0 Then Return

        EditAuthUser.Text = sAuthUser
        EditPassword.Text = sAuthPwd

        EditServerAddr.Text = sServerAddr
        EditServerPort.Text = nServerPort.ToString()

        CheckBoxRegLine.Checked = bRegister

        UpdateLineTypeUI(nLineType)
        UpdateAudioCodecUI(sAudioCodecList)

        UpdateIncomingCallUI(sToPeerName, bRejected, sRoomName)

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub UpdateAudioCodecUI(ByVal sAudioCodecList As String)

        ListBoxEnableCodec.Items.Clear()
        ListBoxDisableCodec.Items.Clear()

        For nCount As Integer = 0 To cVaxServerCOM.VAX_CODEC_TOTAL_COUNT - 1
            ListBoxDisableCodec.Items.Add(cCodec.GetCodecName(nCount))
        Next

        Dim sCodecName As String = ""

        For nCount As Integer = 0 To sAudioCodecList.Length - 1
            sCodecName = cCodec.GetCodecName(sAudioCodecList(nCount))
            ListBoxEnableCodec.Items.Add(sCodecName)
            ListBoxDisableCodec.Items.Remove(sCodecName)
        Next

    End Sub

    Private Function GetAudioCodecUI() As String

        Dim sCodec As String = ""

        For nCount As Integer = 0 To ListBoxEnableCodec.Items.Count - 1
            sCodec += cCodec.GetCodecNo(CStr(ListBoxEnableCodec.Items(nCount)))
        Next

        Return sCodec

    End Function

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub UpdateLineTypeUI(ByVal nLineType As Integer)

        If nLineType = cVaxServerCOM.VAX_LINE_TYPE_UDP Then
            RadioLineTypeUDP.Checked = True

        ElseIf nLineType = cVaxServerCOM.VAX_LINE_TYPE_TCP Then
            RadioLineTypeTCP.Checked = True

        ElseIf nLineType = cVaxServerCOM.VAX_LINE_TYPE_TLS Then
            RadioLineTypeTLS.Checked = True
        Else
            RadioLineTypeUDP.Checked = True
        End If

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Function GetLineTypeUI() As Integer

        If RadioLineTypeUDP.Checked = True Then
            Return cVaxServerCOM.VAX_LINE_TYPE_UDP
        End If

        If RadioLineTypeTCP.Checked = True Then
            Return cVaxServerCOM.VAX_LINE_TYPE_TCP
        End If

        If RadioLineTypeTLS.Checked = True Then
            Return cVaxServerCOM.VAX_LINE_TYPE_TLS
        End If

        Return cVaxServerCOM.VAX_LINE_TYPE_UDP

    End Function

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub GetIncomingCallInfo(ByRef sToPeerName As String, ByRef bRejected As Boolean, ByRef sRoomName As String)

        bRejected = RadioRejectCall.Checked

        If RadioConnectToLogin.Checked Then
            sToPeerName = ComboConnectToLogin.Text.Trim().ToString()

        ElseIf RadioConnectToRoom.Checked Then
            sRoomName = ComboConnectToRoom.Text.Trim().ToString()

        End If

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub UpdateIncomingCallUI(ByVal sToPeerName As String, ByVal bRejected As Boolean, ByVal sRoomName As String)

        If bRejected Then
            RadioRejectCall.Checked = True

        ElseIf sToPeerName.Length <> 0 Then

            Dim nIndex As Integer = ComboConnectToLogin.FindStringExact(sToPeerName)
            If nIndex = -1 Then Return

            If ComboConnectToLogin.Items.Count > 0 Then ComboConnectToLogin.SelectedIndex = nIndex
            RadioConnectToLogin.Checked = True

        ElseIf sRoomName.Length <> 0 Then

            Dim nIndex As Integer = ComboConnectToRoom.FindStringExact(sRoomName)
            If nIndex = -1 Then Return

            If ComboConnectToRoom.Items.Count > 0 Then ComboConnectToRoom.SelectedIndex = nIndex
            RadioConnectToRoom.Checked = True

        End If

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub ClearDlgUI()

        ComboLine.Text = ""

        EditAuthUser.Text = ""
        EditPassword.Text = ""

        CheckBoxRegLine.Checked = False

        EditServerAddr.Text = ""
        EditServerPort.Text = Convert.ToString(cVaxServerCOM.SIP_DEFAULT_PORT)

        If ComboConnectToLogin.Items.Count > 0 Then
            ComboConnectToLogin.SelectedIndex = 0
        End If

        If ComboConnectToRoom.Items.Count > 0 Then
            ComboConnectToRoom.SelectedIndex = 0
        End If

        RadioRejectCall.Checked = True
        RadioLineTypeUDP.Checked = True

        ListBoxEnableCodec.Items.Clear()
        ListBoxDisableCodec.Items.Clear()

        ListBoxEnableCodec.Items.Add(cCodec.AUDIO_CODEC_NAME_G711U)
        ListBoxEnableCodec.Items.Add(cCodec.AUDIO_CODEC_NAME_G711A)
        ListBoxEnableCodec.Items.Add(cCodec.AUDIO_CODEC_NAME_ILBC)
        ListBoxEnableCodec.Items.Add(cCodec.AUDIO_CODEC_NAME_GSM610)
        ListBoxEnableCodec.Items.Add(cCodec.AUDIO_CODEC_NAME_G729)

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Function AddLineChecks() As Boolean

        If ComboLine.Text.Length = 0 Then
            MessageBox.Show("Please enter Line Name.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return False
        End If

        If ListBoxEnableCodec.Items.Count = 0 Then
            MessageBox.Show("Please select a codec.", "VaxVoIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
            Return False
        End If

        Return True

    End Function

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub BtnDisableCodec_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnDisableCodec.Click

        If ListBoxEnableCodec.SelectedItems.Count = 0 Then Return

        ListBoxDisableCodec.Items.Add(ListBoxEnableCodec.SelectedItem.ToString())
        ListBoxEnableCodec.Items.Remove(ListBoxEnableCodec.SelectedItem)

    End Sub

    Private Sub BtnEnableCodec_Click(ByVal sender As Object, ByVal e As EventArgs) Handles BtnEnableCodec.Click

        If ListBoxDisableCodec.SelectedItems.Count = 0 Then Return

        ListBoxEnableCodec.Items.Add(ListBoxDisableCodec.SelectedItem.ToString())
        ListBoxDisableCodec.Items.Remove(ListBoxDisableCodec.SelectedItem)

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

    Private Sub AddLines()

        ComboLine.Items.Clear()
        RadioRejectCall.Checked = True

        Dim objListLines As ArrayList = New ArrayList()
        cStoreLine.GetLineNameAll(objListLines)

        If objListLines.Count <= 0 Then
            Return
        End If

        For nCount As Integer = 0 To objListLines.Count - 1
            ComboLine.Items.Add(objListLines(nCount))
        Next

        If ComboLine.Items.Count > 0 Then
            ComboLine.SelectedIndex = 0
        End If

    End Sub

    Private Sub AddUsers()

        ComboConnectToLogin.Items.Clear()

        Dim objList As ArrayList = New ArrayList()
        cStoreUser.GetUserAll(objList)

        If objList.Count <= 0 Then Return

        For nCount As Integer = 0 To objList.Count - 1
            ComboConnectToLogin.Items.Add(objList(nCount))
        Next

        If ComboConnectToLogin.Items.Count > 0 Then
            ComboConnectToLogin.SelectedIndex = 0
        End If

    End Sub

    Private Sub AddRooms()

        ComboConnectToRoom.Items.Clear()

        Dim objList As ArrayList = New ArrayList()
        cStoreRoom.GetRoomNameAll(objList)

        If objList.Count <= 0 Then Return

        For nCount As Integer = 0 To objList.Count - 1
            ComboConnectToRoom.Items.Add(objList(nCount))
        Next

        If ComboConnectToRoom.Items.Count > 0 Then
            ComboConnectToRoom.SelectedIndex = 0
        End If

    End Sub

    '//////////////////////////////////////////////////////////////////////////
    '//////////////////////////////////////////////////////////////////////////

End Class

